#
# spec file for package aws-iam-authenticator
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aws-iam-authenticator
Version:        0.5.3
Release:        150000.1.9.1
Summary:        Authenticate to Kubernetes cluster using AWS IAM credentials
License:        Apache-2.0
Group:          Development/Languages/Other
URL:            https://aws.amazon.com/sdk-for-go/
Source0:        https://github.com/kubernetes-sigs/aws-iam-authenticator/archive/v%{version}.tar.gz
Patch0:         0001-Add-query-parameter-validation-for-multiple-parameters.patch
BuildRequires:  golang-packaging

%{go_nostrip}
%{go_provides}

%description
A tool to use AWS IAM credentials to authenticate to a Kubernetes cluster

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1

%build
%{goprep} sigs.k8s.io/aws-iam-authenticator
export GOPATH=%{_builddir}/go
cd %{_builddir}/go/src/sigs.k8s.io/aws-iam-authenticator
export GO111MODULE=off
go list ./... | xargs -n1 go build -v

%install
install -Dm 755 %{_builddir}/go/src/sigs.k8s.io/aws-iam-authenticator/aws-iam-authenticator %{buildroot}%{_bindir}/aws-iam-authenticator

%files
%doc README.md
%license LICENSE
%{_bindir}/aws-iam-authenticator

%changelog
* Tue Jul 12 2022 adrian.glaubitz@suse.com
- Add patch to fix AccessKeyID validation bypass (bsc#1201395, CVE-2022-2385)
  * 0001-Add-query-parameter-validation-for-multiple-parameters.patch
* Thu Mar 31 2022 adrian.glaubitz@suse.com
- Update in SLE-15 (bsc#1197703)
* Thu May 20 2021 adrian.glaubitz@suse.com
- Update to version 0.5.3
  * Bump Go to 1.15 in Travis (#361)
  * Update aws sdk go v1.37.1 (#360)
  * (arn): validate partition against all partitions returned by the aws sdk (#348)
  * Document AccessKeyId from UserInfo (#332)
  * Support IPv6 listen address (#352)
  * Added user agent to AWS SDK (#359)
  * Remove Chris Hein from OWNERS (#351)
  * Add instructions for the release process (#346)
- from version 0.5.2
  * Added partition flag (#341)
  * Update link to Kops docs site (#338)
  * Security Improvements on the example yaml (#335)
  * Fix RBAC on example file: service account requires get to ConfigMap (#334)
  * Add AccessKeyID as variable for username (#337)
  * Added server side AWS account ID log redaction (#327)
- from version 0.5.1
  * Update examples/README (#317)
  * Changelog gen (#318)
  * Fix CRD mapper blocking all others because caches
    never sync and revamp backend-mode flag (#303)
  * Update aws-sdk-go to version v1.30.0 (#306)
  * Bump k8s.io/ dependencies to 1.16.8 (#305)
  * chown aws-iam-authenticator to avoid permission denied (#302)
  * Indentation and unit test improvements (#298)
  * Adding Rate limiting ec2:DescribeInstances API
    along with Batching for high TPS (#292)
  * Restrict ClusterRole to readonly IAMIdentityMapping access (#287)
  * added selector to spec and changed from extenstions to apps/v1 (#291)
  * Add AWS AccessKeyID as an extra field in UserInfo (#286)
  * Allow server port customization (#278)
- from version 0.5.0
  * Remove DNS-1123 validation of usernames and groups (#260)
  * switch to use regional sts endpoint & imdsV2 (#283)
  * Add AWS Access Key ID to log (#282)
  * Require to pass in interface instead of the concrete type (#279)
  * Refactor to allow configurable backends (configmap, eks configmap, crd) (#269)
  * Update go version (#255)
  * Adding session name parameter to TokenGenerator (#272)
  * Rename prometheus metrics to match new project name (#249)
  * Remove inactive approvers, add wongma7 (#266)
  * Update aws-sdk-go to v1.23.11 (257)
  * Added go module download check (#259)
  * Updating goreleaser yaml to fix deprecated options (#252)
  * Remove deprecated language from README (#244)
  * Lowercase ARN inside doMapping and log about it (#239)
  * IAMIdentityMapping CRD Implementation (#116)
  * Adding micahhausler as approver (#237)
  * add support for passing externalID to assume role (#228)
  * Update README.md (#231)
  * Using sigs.k8s.io domain instead of github.com (#223)
  * Refactored EC2 API calls to be testable (#226)
  * Include aws request ID when logging errors (#178)
- Remove global Go project variables
- Set GO111MODULE=off to force use of vendored modules
- Update Go build paths
* Thu May 23 2019 adrian.glaubitz@suse.com
- Include in SLE-15 (fate#327747, bsc#1098521)
* Tue May 14 2019 adrian.glaubitz@suse.com
- Initial build
  + Version 0.4.0
